token

package
v0.38.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 15, 2026 License: MIT Imports: 2 Imported by: 3

Documentation

Overview

Package token provides JWT claim types and helpers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ClaimStrings

type ClaimStrings []string

ClaimStrings is basically just a slice of strings, but it can be either serialized from a string array or just a string.

func (*ClaimStrings) MarshalJSON

func (s *ClaimStrings) MarshalJSON() ([]byte, error)

MarshalJSON implements json.Marshaler for ClaimStrings.

func (*ClaimStrings) UnmarshalJSON

func (s *ClaimStrings) UnmarshalJSON(data []byte) error

UnmarshalJSON implements json.Unmarshaler for ClaimStrings.

func (*ClaimStrings) Value

func (s *ClaimStrings) Value() string

Value of the claim as string.

Directories

Path Synopsis
Package nonce provides nonce store implementations for WS-Federation.
Package nonce provides nonce store implementations for WS-Federation.

Jump to