Documentation
¶
Overview ¶
Package token provides JWT claim types and helpers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClaimStrings ¶
type ClaimStrings []string
ClaimStrings is basically just a slice of strings, but it can be either serialized from a string array or just a string.
func (*ClaimStrings) MarshalJSON ¶
func (s *ClaimStrings) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler for ClaimStrings.
func (*ClaimStrings) UnmarshalJSON ¶
func (s *ClaimStrings) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler for ClaimStrings.
Click to show internal directories.
Click to hide internal directories.